"""
>>> sort_districts(Path('data/districts.txt'), Path('data/regions'))

>>> import testing; testing.diff('data/Jihomoravský-expected.txt', 'data/regions/Jihomoravský.txt')
Files are identical

"""


from pathlib import Path


def sort_districts(input_file: Path, output_dir: Path) -> None:
    districts_per_region = {}
    with open(input_file, encoding='utf8') as r:
        for line in r:
            if line.strip() == '':
                continue
            district, region = line.split(':')
            district = district.strip()
            region = region.strip()
            if region not in districts_per_region:
                districts_per_region[region] = []
            districts_per_region[region].append(district)
    output_dir.mkdir(parents=True, exist_ok=True)
    for region, districts in districts_per_region.items():
        with open(output_dir / f'{region}.txt', 'w', encoding='utf8') as w:
            for district in districts:
                print(district, file=w)


if __name__ == '__main__':
    sort_districts(Path('data/districts.txt'), Path('data/regions'))
